@@ -1,7 +1,7 @@
-from .invenio_base import InvenioBaseClassPythonBuilder
 from oarepo_model_builder.outputs.python import PythonOutput
 from oarepo_model_builder.utils.hyphen_munch import HyphenMunch
-from ..utils.jinja import base_name
+
+from .invenio_base import InvenioBaseClassPythonBuilder
 
 
 class InvenioRecordServiceConfigBuilder(InvenioBaseClassPythonBuilder):
@@ -15,9 +15,7 @@ class InvenioRecordServiceConfigBuilder(InvenioBaseClassPythonBuilder):
         output: PythonOutput = self.builder.get_output("python", python_path)
 
         context = HyphenMunch(
-            settings=self.settings,
-            current_model=self.current_model,
-            **extra_kwargs
+            settings=self.settings, current_model=self.current_model, **extra_kwargs
         )
         template = self.call_components(
             "invenio_before_python_template", template, context=context
