@@ -1,14 +1,15 @@
 from pathlib import Path
 
-import pkg_resources
+from importlib_metadata import entry_points
 
 
 class TemplateRegistry:
     def __init__(self):
         self.mapping = {}
+        eps = entry_points()
         for ep in reversed(
             sorted(
-                pkg_resources.iter_entry_points("oarepo_model_builder.templates"),
+                eps.select(group="oarepo_model_builder.templates"),
                 key=lambda ep: ep.name,
             )
         ):
@@ -19,7 +20,9 @@ class TemplateRegistry:
 
     def get_template(self, template_key, settings):
         # try to get the template key from settings
-        path = settings.python.templates.get(template_key, self.mapping.get(template_key, None))
+        path = settings.python.templates.get(
+            template_key, self.mapping.get(template_key, None)
+        )
         if not path:
             raise AttributeError(f"Template with key {template_key} has not been found")
         if isinstance(path, str):
@@ -27,7 +30,9 @@ class TemplateRegistry:
         if path.exists():
             with path.open() as f:
                 return f.read()
-        raise AttributeError(f"Template with key {template_key} has not been found, file at path {path} does not exist")
+        raise AttributeError(
+            f"Template with key {template_key} has not been found, file at path {path} does not exist"
+        )
 
 
 templates = TemplateRegistry()
