@@ -35,7 +35,7 @@ def test_enum():
         """
 from invenio_records_resources.services.records.schema import BaseRecordSchema as InvenioBaseRecordSchema
 from marshmallow import ValidationError
-from marshmallow import validates as ma_validates
+from marshmallow import validate as ma_validate
 import marshmallow as ma
 from marshmallow import fields as ma_fields
 from marshmallow_utils import fields as mu_fields
